# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_accounts_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_accounts_rpc.proto',
  package='injective_accounts_rpc',
  syntax='proto3',
  serialized_options=b'Z\031/injective_accounts_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%exchange/injective_accounts_rpc.proto\x12\x16injective_accounts_rpc\"+\n\x10PortfolioRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\"P\n\x11PortfolioResponse\x12;\n\tportfolio\x18\x01 \x01(\x0b\x32(.injective_accounts_rpc.AccountPortfolio\"\xb8\x01\n\x10\x41\x63\x63ountPortfolio\x12\x17\n\x0fportfolio_value\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\x12\x16\n\x0elocked_balance\x18\x03 \x01(\t\x12\x16\n\x0eunrealized_pnl\x18\x04 \x01(\t\x12@\n\x0bsubaccounts\x18\x05 \x03(\x0b\x32+.injective_accounts_rpc.SubaccountPortfolio\"w\n\x13SubaccountPortfolio\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\x12\x16\n\x0elocked_balance\x18\x03 \x01(\t\x12\x16\n\x0eunrealized_pnl\x18\x04 \x01(\t\"P\n\x12OrderStatesRequest\x12\x19\n\x11spot_order_hashes\x18\x01 \x03(\t\x12\x1f\n\x17\x64\x65rivative_order_hashes\x18\x02 \x03(\t\"\xa5\x01\n\x13OrderStatesResponse\x12\x43\n\x11spot_order_states\x18\x01 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecord\x12I\n\x17\x64\x65rivative_order_states\x18\x02 \x03(\x0b\x32(.injective_accounts_rpc.OrderStateRecord\"\xe4\x01\n\x10OrderStateRecord\x12\x12\n\norder_hash\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x12\n\norder_type\x18\x04 \x01(\t\x12\x12\n\norder_side\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x17\n\x0fquantity_filled\x18\x07 \x01(\t\x12\x1a\n\x12quantity_remaining\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\x12\x12\x12\n\nupdated_at\x18\n \x01(\x12\"1\n\x16SubaccountsListRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\".\n\x17SubaccountsListResponse\x12\x13\n\x0bsubaccounts\x18\x01 \x03(\t\"F\n\x1dSubaccountBalancesListRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65noms\x18\x02 \x03(\t\"]\n\x1eSubaccountBalancesListResponse\x12;\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32).injective_accounts_rpc.SubaccountBalance\"\x8e\x01\n\x11SubaccountBalance\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12:\n\x07\x64\x65posit\x18\x04 \x01(\x0b\x32).injective_accounts_rpc.SubaccountDeposit\"E\n\x11SubaccountDeposit\x12\x15\n\rtotal_balance\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\"@\n\x18SubaccountBalanceRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"W\n\x19SubaccountBalanceResponse\x12:\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalance\"G\n\x1eStreamSubaccountBalanceRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65noms\x18\x02 \x03(\t\"p\n\x1fStreamSubaccountBalanceResponse\x12:\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective_accounts_rpc.SubaccountBalance\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\"\x87\x01\n\x18SubaccountHistoryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x16\n\x0etransfer_types\x18\x03 \x03(\t\x12\x0c\n\x04skip\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x11\x12\x10\n\x08\x65nd_time\x18\x06 \x01(\x12\"\x91\x01\n\x19SubaccountHistoryResponse\x12\x44\n\ttransfers\x18\x01 \x03(\x0b\x32\x31.injective_accounts_rpc.SubaccountBalanceTransfer\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x1e.injective_accounts_rpc.Paging\"\xeb\x01\n\x19SubaccountBalanceTransfer\x12\x15\n\rtransfer_type\x18\x01 \x01(\t\x12\x19\n\x11src_subaccount_id\x18\x02 \x01(\t\x12\x1b\n\x13src_account_address\x18\x03 \x01(\t\x12\x19\n\x11\x64st_subaccount_id\x18\x04 \x01(\t\x12\x1b\n\x13\x64st_account_address\x18\x05 \x01(\t\x12\x32\n\x06\x61mount\x18\x06 \x01(\x0b\x32\".injective_accounts_rpc.CosmosCoin\x12\x13\n\x0b\x65xecuted_at\x18\x07 \x01(\x12\"+\n\nCosmosCoin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"1\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\"b\n\x1dSubaccountOrderSummaryRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x17\n\x0forder_direction\x18\x03 \x01(\t\"\\\n\x1eSubaccountOrderSummaryResponse\x12\x19\n\x11spot_orders_total\x18\x01 \x01(\x12\x12\x1f\n\x17\x64\x65rivative_orders_total\x18\x02 \x01(\x12\"8\n\x0eRewardsRequest\x12\r\n\x05\x65poch\x18\x01 \x01(\x12\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\"B\n\x0fRewardsResponse\x12/\n\x07rewards\x18\x01 \x03(\x0b\x32\x1e.injective_accounts_rpc.Reward\"h\n\x06Reward\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12-\n\x07rewards\x18\x02 \x03(\x0b\x32\x1c.injective_accounts_rpc.Coin\x12\x16\n\x0e\x64istributed_at\x18\x03 \x01(\x12\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t2\xd0\x08\n\x14InjectiveAccountsRPC\x12`\n\tPortfolio\x12(.injective_accounts_rpc.PortfolioRequest\x1a).injective_accounts_rpc.PortfolioResponse\x12\x66\n\x0bOrderStates\x12*.injective_accounts_rpc.OrderStatesRequest\x1a+.injective_accounts_rpc.OrderStatesResponse\x12r\n\x0fSubaccountsList\x12..injective_accounts_rpc.SubaccountsListRequest\x1a/.injective_accounts_rpc.SubaccountsListResponse\x12\x87\x01\n\x16SubaccountBalancesList\x12\x35.injective_accounts_rpc.SubaccountBalancesListRequest\x1a\x36.injective_accounts_rpc.SubaccountBalancesListResponse\x12\x80\x01\n\x19SubaccountBalanceEndpoint\x12\x30.injective_accounts_rpc.SubaccountBalanceRequest\x1a\x31.injective_accounts_rpc.SubaccountBalanceResponse\x12\x8c\x01\n\x17StreamSubaccountBalance\x12\x36.injective_accounts_rpc.StreamSubaccountBalanceRequest\x1a\x37.injective_accounts_rpc.StreamSubaccountBalanceResponse0\x01\x12x\n\x11SubaccountHistory\x12\x30.injective_accounts_rpc.SubaccountHistoryRequest\x1a\x31.injective_accounts_rpc.SubaccountHistoryResponse\x12\x87\x01\n\x16SubaccountOrderSummary\x12\x35.injective_accounts_rpc.SubaccountOrderSummaryRequest\x1a\x36.injective_accounts_rpc.SubaccountOrderSummaryResponse\x12Z\n\x07Rewards\x12&.injective_accounts_rpc.RewardsRequest\x1a\'.injective_accounts_rpc.RewardsResponseB\x1bZ\x19/injective_accounts_rpcpbb\x06proto3'
)




_PORTFOLIOREQUEST = _descriptor.Descriptor(
  name='PortfolioRequest',
  full_name='injective_accounts_rpc.PortfolioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_address', full_name='injective_accounts_rpc.PortfolioRequest.account_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=108,
)


_PORTFOLIORESPONSE = _descriptor.Descriptor(
  name='PortfolioResponse',
  full_name='injective_accounts_rpc.PortfolioResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='portfolio', full_name='injective_accounts_rpc.PortfolioResponse.portfolio', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=190,
)


_ACCOUNTPORTFOLIO = _descriptor.Descriptor(
  name='AccountPortfolio',
  full_name='injective_accounts_rpc.AccountPortfolio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='portfolio_value', full_name='injective_accounts_rpc.AccountPortfolio.portfolio_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_balance', full_name='injective_accounts_rpc.AccountPortfolio.available_balance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked_balance', full_name='injective_accounts_rpc.AccountPortfolio.locked_balance', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unrealized_pnl', full_name='injective_accounts_rpc.AccountPortfolio.unrealized_pnl', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccounts', full_name='injective_accounts_rpc.AccountPortfolio.subaccounts', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=377,
)


_SUBACCOUNTPORTFOLIO = _descriptor.Descriptor(
  name='SubaccountPortfolio',
  full_name='injective_accounts_rpc.SubaccountPortfolio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.SubaccountPortfolio.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_balance', full_name='injective_accounts_rpc.SubaccountPortfolio.available_balance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked_balance', full_name='injective_accounts_rpc.SubaccountPortfolio.locked_balance', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unrealized_pnl', full_name='injective_accounts_rpc.SubaccountPortfolio.unrealized_pnl', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=498,
)


_ORDERSTATESREQUEST = _descriptor.Descriptor(
  name='OrderStatesRequest',
  full_name='injective_accounts_rpc.OrderStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spot_order_hashes', full_name='injective_accounts_rpc.OrderStatesRequest.spot_order_hashes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_order_hashes', full_name='injective_accounts_rpc.OrderStatesRequest.derivative_order_hashes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=580,
)


_ORDERSTATESRESPONSE = _descriptor.Descriptor(
  name='OrderStatesResponse',
  full_name='injective_accounts_rpc.OrderStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spot_order_states', full_name='injective_accounts_rpc.OrderStatesResponse.spot_order_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_order_states', full_name='injective_accounts_rpc.OrderStatesResponse.derivative_order_states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=748,
)


_ORDERSTATERECORD = _descriptor.Descriptor(
  name='OrderStateRecord',
  full_name='injective_accounts_rpc.OrderStateRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective_accounts_rpc.OrderStateRecord.order_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.OrderStateRecord.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_accounts_rpc.OrderStateRecord.market_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective_accounts_rpc.OrderStateRecord.order_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_side', full_name='injective_accounts_rpc.OrderStateRecord.order_side', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='injective_accounts_rpc.OrderStateRecord.state', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity_filled', full_name='injective_accounts_rpc.OrderStateRecord.quantity_filled', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity_remaining', full_name='injective_accounts_rpc.OrderStateRecord.quantity_remaining', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='injective_accounts_rpc.OrderStateRecord.created_at', index=8,
      number=9, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_accounts_rpc.OrderStateRecord.updated_at', index=9,
      number=10, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=979,
)


_SUBACCOUNTSLISTREQUEST = _descriptor.Descriptor(
  name='SubaccountsListRequest',
  full_name='injective_accounts_rpc.SubaccountsListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_address', full_name='injective_accounts_rpc.SubaccountsListRequest.account_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1030,
)


_SUBACCOUNTSLISTRESPONSE = _descriptor.Descriptor(
  name='SubaccountsListResponse',
  full_name='injective_accounts_rpc.SubaccountsListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccounts', full_name='injective_accounts_rpc.SubaccountsListResponse.subaccounts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1032,
  serialized_end=1078,
)


_SUBACCOUNTBALANCESLISTREQUEST = _descriptor.Descriptor(
  name='SubaccountBalancesListRequest',
  full_name='injective_accounts_rpc.SubaccountBalancesListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.SubaccountBalancesListRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denoms', full_name='injective_accounts_rpc.SubaccountBalancesListRequest.denoms', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1080,
  serialized_end=1150,
)


_SUBACCOUNTBALANCESLISTRESPONSE = _descriptor.Descriptor(
  name='SubaccountBalancesListResponse',
  full_name='injective_accounts_rpc.SubaccountBalancesListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balances', full_name='injective_accounts_rpc.SubaccountBalancesListResponse.balances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1152,
  serialized_end=1245,
)


_SUBACCOUNTBALANCE = _descriptor.Descriptor(
  name='SubaccountBalance',
  full_name='injective_accounts_rpc.SubaccountBalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.SubaccountBalance.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_address', full_name='injective_accounts_rpc.SubaccountBalance.account_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective_accounts_rpc.SubaccountBalance.denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='injective_accounts_rpc.SubaccountBalance.deposit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1390,
)


_SUBACCOUNTDEPOSIT = _descriptor.Descriptor(
  name='SubaccountDeposit',
  full_name='injective_accounts_rpc.SubaccountDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_balance', full_name='injective_accounts_rpc.SubaccountDeposit.total_balance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_balance', full_name='injective_accounts_rpc.SubaccountDeposit.available_balance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1461,
)


_SUBACCOUNTBALANCEREQUEST = _descriptor.Descriptor(
  name='SubaccountBalanceRequest',
  full_name='injective_accounts_rpc.SubaccountBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.SubaccountBalanceRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective_accounts_rpc.SubaccountBalanceRequest.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1527,
)


_SUBACCOUNTBALANCERESPONSE = _descriptor.Descriptor(
  name='SubaccountBalanceResponse',
  full_name='injective_accounts_rpc.SubaccountBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance', full_name='injective_accounts_rpc.SubaccountBalanceResponse.balance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=1616,
)


_STREAMSUBACCOUNTBALANCEREQUEST = _descriptor.Descriptor(
  name='StreamSubaccountBalanceRequest',
  full_name='injective_accounts_rpc.StreamSubaccountBalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.StreamSubaccountBalanceRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denoms', full_name='injective_accounts_rpc.StreamSubaccountBalanceRequest.denoms', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1618,
  serialized_end=1689,
)


_STREAMSUBACCOUNTBALANCERESPONSE = _descriptor.Descriptor(
  name='StreamSubaccountBalanceResponse',
  full_name='injective_accounts_rpc.StreamSubaccountBalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance', full_name='injective_accounts_rpc.StreamSubaccountBalanceResponse.balance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_accounts_rpc.StreamSubaccountBalanceResponse.timestamp', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1691,
  serialized_end=1803,
)


_SUBACCOUNTHISTORYREQUEST = _descriptor.Descriptor(
  name='SubaccountHistoryRequest',
  full_name='injective_accounts_rpc.SubaccountHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.SubaccountHistoryRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective_accounts_rpc.SubaccountHistoryRequest.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer_types', full_name='injective_accounts_rpc.SubaccountHistoryRequest.transfer_types', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip', full_name='injective_accounts_rpc.SubaccountHistoryRequest.skip', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective_accounts_rpc.SubaccountHistoryRequest.limit', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='injective_accounts_rpc.SubaccountHistoryRequest.end_time', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1941,
)


_SUBACCOUNTHISTORYRESPONSE = _descriptor.Descriptor(
  name='SubaccountHistoryResponse',
  full_name='injective_accounts_rpc.SubaccountHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfers', full_name='injective_accounts_rpc.SubaccountHistoryResponse.transfers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paging', full_name='injective_accounts_rpc.SubaccountHistoryResponse.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1944,
  serialized_end=2089,
)


_SUBACCOUNTBALANCETRANSFER = _descriptor.Descriptor(
  name='SubaccountBalanceTransfer',
  full_name='injective_accounts_rpc.SubaccountBalanceTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer_type', full_name='injective_accounts_rpc.SubaccountBalanceTransfer.transfer_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_subaccount_id', full_name='injective_accounts_rpc.SubaccountBalanceTransfer.src_subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src_account_address', full_name='injective_accounts_rpc.SubaccountBalanceTransfer.src_account_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_subaccount_id', full_name='injective_accounts_rpc.SubaccountBalanceTransfer.dst_subaccount_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_account_address', full_name='injective_accounts_rpc.SubaccountBalanceTransfer.dst_account_address', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_accounts_rpc.SubaccountBalanceTransfer.amount', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executed_at', full_name='injective_accounts_rpc.SubaccountBalanceTransfer.executed_at', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2092,
  serialized_end=2327,
)


_COSMOSCOIN = _descriptor.Descriptor(
  name='CosmosCoin',
  full_name='injective_accounts_rpc.CosmosCoin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective_accounts_rpc.CosmosCoin.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_accounts_rpc.CosmosCoin.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2329,
  serialized_end=2372,
)


_PAGING = _descriptor.Descriptor(
  name='Paging',
  full_name='injective_accounts_rpc.Paging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='injective_accounts_rpc.Paging.total', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='injective_accounts_rpc.Paging.from', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='injective_accounts_rpc.Paging.to', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2374,
  serialized_end=2423,
)


_SUBACCOUNTORDERSUMMARYREQUEST = _descriptor.Descriptor(
  name='SubaccountOrderSummaryRequest',
  full_name='injective_accounts_rpc.SubaccountOrderSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective_accounts_rpc.SubaccountOrderSummaryRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_accounts_rpc.SubaccountOrderSummaryRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_direction', full_name='injective_accounts_rpc.SubaccountOrderSummaryRequest.order_direction', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2425,
  serialized_end=2523,
)


_SUBACCOUNTORDERSUMMARYRESPONSE = _descriptor.Descriptor(
  name='SubaccountOrderSummaryResponse',
  full_name='injective_accounts_rpc.SubaccountOrderSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spot_orders_total', full_name='injective_accounts_rpc.SubaccountOrderSummaryResponse.spot_orders_total', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_orders_total', full_name='injective_accounts_rpc.SubaccountOrderSummaryResponse.derivative_orders_total', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2525,
  serialized_end=2617,
)


_REWARDSREQUEST = _descriptor.Descriptor(
  name='RewardsRequest',
  full_name='injective_accounts_rpc.RewardsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epoch', full_name='injective_accounts_rpc.RewardsRequest.epoch', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_address', full_name='injective_accounts_rpc.RewardsRequest.account_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2619,
  serialized_end=2675,
)


_REWARDSRESPONSE = _descriptor.Descriptor(
  name='RewardsResponse',
  full_name='injective_accounts_rpc.RewardsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rewards', full_name='injective_accounts_rpc.RewardsResponse.rewards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2677,
  serialized_end=2743,
)


_REWARD = _descriptor.Descriptor(
  name='Reward',
  full_name='injective_accounts_rpc.Reward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_address', full_name='injective_accounts_rpc.Reward.account_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='injective_accounts_rpc.Reward.rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distributed_at', full_name='injective_accounts_rpc.Reward.distributed_at', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2745,
  serialized_end=2849,
)


_COIN = _descriptor.Descriptor(
  name='Coin',
  full_name='injective_accounts_rpc.Coin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective_accounts_rpc.Coin.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_accounts_rpc.Coin.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2851,
  serialized_end=2888,
)

_PORTFOLIORESPONSE.fields_by_name['portfolio'].message_type = _ACCOUNTPORTFOLIO
_ACCOUNTPORTFOLIO.fields_by_name['subaccounts'].message_type = _SUBACCOUNTPORTFOLIO
_ORDERSTATESRESPONSE.fields_by_name['spot_order_states'].message_type = _ORDERSTATERECORD
_ORDERSTATESRESPONSE.fields_by_name['derivative_order_states'].message_type = _ORDERSTATERECORD
_SUBACCOUNTBALANCESLISTRESPONSE.fields_by_name['balances'].message_type = _SUBACCOUNTBALANCE
_SUBACCOUNTBALANCE.fields_by_name['deposit'].message_type = _SUBACCOUNTDEPOSIT
_SUBACCOUNTBALANCERESPONSE.fields_by_name['balance'].message_type = _SUBACCOUNTBALANCE
_STREAMSUBACCOUNTBALANCERESPONSE.fields_by_name['balance'].message_type = _SUBACCOUNTBALANCE
_SUBACCOUNTHISTORYRESPONSE.fields_by_name['transfers'].message_type = _SUBACCOUNTBALANCETRANSFER
_SUBACCOUNTHISTORYRESPONSE.fields_by_name['paging'].message_type = _PAGING
_SUBACCOUNTBALANCETRANSFER.fields_by_name['amount'].message_type = _COSMOSCOIN
_REWARDSRESPONSE.fields_by_name['rewards'].message_type = _REWARD
_REWARD.fields_by_name['rewards'].message_type = _COIN
DESCRIPTOR.message_types_by_name['PortfolioRequest'] = _PORTFOLIOREQUEST
DESCRIPTOR.message_types_by_name['PortfolioResponse'] = _PORTFOLIORESPONSE
DESCRIPTOR.message_types_by_name['AccountPortfolio'] = _ACCOUNTPORTFOLIO
DESCRIPTOR.message_types_by_name['SubaccountPortfolio'] = _SUBACCOUNTPORTFOLIO
DESCRIPTOR.message_types_by_name['OrderStatesRequest'] = _ORDERSTATESREQUEST
DESCRIPTOR.message_types_by_name['OrderStatesResponse'] = _ORDERSTATESRESPONSE
DESCRIPTOR.message_types_by_name['OrderStateRecord'] = _ORDERSTATERECORD
DESCRIPTOR.message_types_by_name['SubaccountsListRequest'] = _SUBACCOUNTSLISTREQUEST
DESCRIPTOR.message_types_by_name['SubaccountsListResponse'] = _SUBACCOUNTSLISTRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountBalancesListRequest'] = _SUBACCOUNTBALANCESLISTREQUEST
DESCRIPTOR.message_types_by_name['SubaccountBalancesListResponse'] = _SUBACCOUNTBALANCESLISTRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountBalance'] = _SUBACCOUNTBALANCE
DESCRIPTOR.message_types_by_name['SubaccountDeposit'] = _SUBACCOUNTDEPOSIT
DESCRIPTOR.message_types_by_name['SubaccountBalanceRequest'] = _SUBACCOUNTBALANCEREQUEST
DESCRIPTOR.message_types_by_name['SubaccountBalanceResponse'] = _SUBACCOUNTBALANCERESPONSE
DESCRIPTOR.message_types_by_name['StreamSubaccountBalanceRequest'] = _STREAMSUBACCOUNTBALANCEREQUEST
DESCRIPTOR.message_types_by_name['StreamSubaccountBalanceResponse'] = _STREAMSUBACCOUNTBALANCERESPONSE
DESCRIPTOR.message_types_by_name['SubaccountHistoryRequest'] = _SUBACCOUNTHISTORYREQUEST
DESCRIPTOR.message_types_by_name['SubaccountHistoryResponse'] = _SUBACCOUNTHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountBalanceTransfer'] = _SUBACCOUNTBALANCETRANSFER
DESCRIPTOR.message_types_by_name['CosmosCoin'] = _COSMOSCOIN
DESCRIPTOR.message_types_by_name['Paging'] = _PAGING
DESCRIPTOR.message_types_by_name['SubaccountOrderSummaryRequest'] = _SUBACCOUNTORDERSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['SubaccountOrderSummaryResponse'] = _SUBACCOUNTORDERSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['RewardsRequest'] = _REWARDSREQUEST
DESCRIPTOR.message_types_by_name['RewardsResponse'] = _REWARDSRESPONSE
DESCRIPTOR.message_types_by_name['Reward'] = _REWARD
DESCRIPTOR.message_types_by_name['Coin'] = _COIN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PortfolioRequest = _reflection.GeneratedProtocolMessageType('PortfolioRequest', (_message.Message,), {
  'DESCRIPTOR' : _PORTFOLIOREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.PortfolioRequest)
  })
_sym_db.RegisterMessage(PortfolioRequest)

PortfolioResponse = _reflection.GeneratedProtocolMessageType('PortfolioResponse', (_message.Message,), {
  'DESCRIPTOR' : _PORTFOLIORESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.PortfolioResponse)
  })
_sym_db.RegisterMessage(PortfolioResponse)

AccountPortfolio = _reflection.GeneratedProtocolMessageType('AccountPortfolio', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPORTFOLIO,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.AccountPortfolio)
  })
_sym_db.RegisterMessage(AccountPortfolio)

SubaccountPortfolio = _reflection.GeneratedProtocolMessageType('SubaccountPortfolio', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTPORTFOLIO,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountPortfolio)
  })
_sym_db.RegisterMessage(SubaccountPortfolio)

OrderStatesRequest = _reflection.GeneratedProtocolMessageType('OrderStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSTATESREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.OrderStatesRequest)
  })
_sym_db.RegisterMessage(OrderStatesRequest)

OrderStatesResponse = _reflection.GeneratedProtocolMessageType('OrderStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSTATESRESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.OrderStatesResponse)
  })
_sym_db.RegisterMessage(OrderStatesResponse)

OrderStateRecord = _reflection.GeneratedProtocolMessageType('OrderStateRecord', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSTATERECORD,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.OrderStateRecord)
  })
_sym_db.RegisterMessage(OrderStateRecord)

SubaccountsListRequest = _reflection.GeneratedProtocolMessageType('SubaccountsListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTSLISTREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountsListRequest)
  })
_sym_db.RegisterMessage(SubaccountsListRequest)

SubaccountsListResponse = _reflection.GeneratedProtocolMessageType('SubaccountsListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTSLISTRESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountsListResponse)
  })
_sym_db.RegisterMessage(SubaccountsListResponse)

SubaccountBalancesListRequest = _reflection.GeneratedProtocolMessageType('SubaccountBalancesListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTBALANCESLISTREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountBalancesListRequest)
  })
_sym_db.RegisterMessage(SubaccountBalancesListRequest)

SubaccountBalancesListResponse = _reflection.GeneratedProtocolMessageType('SubaccountBalancesListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTBALANCESLISTRESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountBalancesListResponse)
  })
_sym_db.RegisterMessage(SubaccountBalancesListResponse)

SubaccountBalance = _reflection.GeneratedProtocolMessageType('SubaccountBalance', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTBALANCE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountBalance)
  })
_sym_db.RegisterMessage(SubaccountBalance)

SubaccountDeposit = _reflection.GeneratedProtocolMessageType('SubaccountDeposit', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTDEPOSIT,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountDeposit)
  })
_sym_db.RegisterMessage(SubaccountDeposit)

SubaccountBalanceRequest = _reflection.GeneratedProtocolMessageType('SubaccountBalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTBALANCEREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountBalanceRequest)
  })
_sym_db.RegisterMessage(SubaccountBalanceRequest)

SubaccountBalanceResponse = _reflection.GeneratedProtocolMessageType('SubaccountBalanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTBALANCERESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountBalanceResponse)
  })
_sym_db.RegisterMessage(SubaccountBalanceResponse)

StreamSubaccountBalanceRequest = _reflection.GeneratedProtocolMessageType('StreamSubaccountBalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSUBACCOUNTBALANCEREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.StreamSubaccountBalanceRequest)
  })
_sym_db.RegisterMessage(StreamSubaccountBalanceRequest)

StreamSubaccountBalanceResponse = _reflection.GeneratedProtocolMessageType('StreamSubaccountBalanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSUBACCOUNTBALANCERESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.StreamSubaccountBalanceResponse)
  })
_sym_db.RegisterMessage(StreamSubaccountBalanceResponse)

SubaccountHistoryRequest = _reflection.GeneratedProtocolMessageType('SubaccountHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTHISTORYREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountHistoryRequest)
  })
_sym_db.RegisterMessage(SubaccountHistoryRequest)

SubaccountHistoryResponse = _reflection.GeneratedProtocolMessageType('SubaccountHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTHISTORYRESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountHistoryResponse)
  })
_sym_db.RegisterMessage(SubaccountHistoryResponse)

SubaccountBalanceTransfer = _reflection.GeneratedProtocolMessageType('SubaccountBalanceTransfer', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTBALANCETRANSFER,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountBalanceTransfer)
  })
_sym_db.RegisterMessage(SubaccountBalanceTransfer)

CosmosCoin = _reflection.GeneratedProtocolMessageType('CosmosCoin', (_message.Message,), {
  'DESCRIPTOR' : _COSMOSCOIN,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.CosmosCoin)
  })
_sym_db.RegisterMessage(CosmosCoin)

Paging = _reflection.GeneratedProtocolMessageType('Paging', (_message.Message,), {
  'DESCRIPTOR' : _PAGING,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.Paging)
  })
_sym_db.RegisterMessage(Paging)

SubaccountOrderSummaryRequest = _reflection.GeneratedProtocolMessageType('SubaccountOrderSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERSUMMARYREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountOrderSummaryRequest)
  })
_sym_db.RegisterMessage(SubaccountOrderSummaryRequest)

SubaccountOrderSummaryResponse = _reflection.GeneratedProtocolMessageType('SubaccountOrderSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERSUMMARYRESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.SubaccountOrderSummaryResponse)
  })
_sym_db.RegisterMessage(SubaccountOrderSummaryResponse)

RewardsRequest = _reflection.GeneratedProtocolMessageType('RewardsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REWARDSREQUEST,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.RewardsRequest)
  })
_sym_db.RegisterMessage(RewardsRequest)

RewardsResponse = _reflection.GeneratedProtocolMessageType('RewardsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REWARDSRESPONSE,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.RewardsResponse)
  })
_sym_db.RegisterMessage(RewardsResponse)

Reward = _reflection.GeneratedProtocolMessageType('Reward', (_message.Message,), {
  'DESCRIPTOR' : _REWARD,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.Reward)
  })
_sym_db.RegisterMessage(Reward)

Coin = _reflection.GeneratedProtocolMessageType('Coin', (_message.Message,), {
  'DESCRIPTOR' : _COIN,
  '__module__' : 'exchange.injective_accounts_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_accounts_rpc.Coin)
  })
_sym_db.RegisterMessage(Coin)


DESCRIPTOR._options = None

_INJECTIVEACCOUNTSRPC = _descriptor.ServiceDescriptor(
  name='InjectiveAccountsRPC',
  full_name='injective_accounts_rpc.InjectiveAccountsRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2891,
  serialized_end=3995,
  methods=[
  _descriptor.MethodDescriptor(
    name='Portfolio',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.Portfolio',
    index=0,
    containing_service=None,
    input_type=_PORTFOLIOREQUEST,
    output_type=_PORTFOLIORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OrderStates',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.OrderStates',
    index=1,
    containing_service=None,
    input_type=_ORDERSTATESREQUEST,
    output_type=_ORDERSTATESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountsList',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.SubaccountsList',
    index=2,
    containing_service=None,
    input_type=_SUBACCOUNTSLISTREQUEST,
    output_type=_SUBACCOUNTSLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountBalancesList',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.SubaccountBalancesList',
    index=3,
    containing_service=None,
    input_type=_SUBACCOUNTBALANCESLISTREQUEST,
    output_type=_SUBACCOUNTBALANCESLISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountBalanceEndpoint',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.SubaccountBalanceEndpoint',
    index=4,
    containing_service=None,
    input_type=_SUBACCOUNTBALANCEREQUEST,
    output_type=_SUBACCOUNTBALANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamSubaccountBalance',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.StreamSubaccountBalance',
    index=5,
    containing_service=None,
    input_type=_STREAMSUBACCOUNTBALANCEREQUEST,
    output_type=_STREAMSUBACCOUNTBALANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountHistory',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.SubaccountHistory',
    index=6,
    containing_service=None,
    input_type=_SUBACCOUNTHISTORYREQUEST,
    output_type=_SUBACCOUNTHISTORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountOrderSummary',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.SubaccountOrderSummary',
    index=7,
    containing_service=None,
    input_type=_SUBACCOUNTORDERSUMMARYREQUEST,
    output_type=_SUBACCOUNTORDERSUMMARYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Rewards',
    full_name='injective_accounts_rpc.InjectiveAccountsRPC.Rewards',
    index=8,
    containing_service=None,
    input_type=_REWARDSREQUEST,
    output_type=_REWARDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEACCOUNTSRPC)

DESCRIPTOR.services_by_name['InjectiveAccountsRPC'] = _INJECTIVEACCOUNTSRPC

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/types/canonical.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/types/canonical.proto',
  package='tendermint.types',
  syntax='proto3',
  serialized_options=b'Z7github.com/tendermint/tendermint/proto/tendermint/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n tendermint/types/canonical.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/types/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"i\n\x10\x43\x61nonicalBlockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12G\n\x0fpart_set_header\x18\x02 \x01(\x0b\x32(.tendermint.types.CanonicalPartSetHeaderB\x04\xc8\xde\x1f\x00\"5\n\x16\x43\x61nonicalPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"\x9d\x02\n\x11\x43\x61nonicalProposal\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x1f\n\tpol_round\x18\x04 \x01(\x03\x42\x0c\xe2\xde\x1f\x08POLRound\x12\x41\n\x08\x62lock_id\x18\x05 \x01(\x0b\x32\".tendermint.types.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08\x63hain_id\x18\x07 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\"\xf8\x01\n\rCanonicalVote\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x10\x12\r\n\x05round\x18\x03 \x01(\x10\x12\x41\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\".tendermint.types.CanonicalBlockIDB\x0b\xe2\xde\x1f\x07\x42lockID\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1d\n\x08\x63hain_id\x18\x06 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainIDB9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_CANONICALBLOCKID = _descriptor.Descriptor(
  name='CanonicalBlockID',
  full_name='tendermint.types.CanonicalBlockID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='tendermint.types.CanonicalBlockID.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='part_set_header', full_name='tendermint.types.CanonicalBlockID.part_set_header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=244,
)


_CANONICALPARTSETHEADER = _descriptor.Descriptor(
  name='CanonicalPartSetHeader',
  full_name='tendermint.types.CanonicalPartSetHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='tendermint.types.CanonicalPartSetHeader.total', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='tendermint.types.CanonicalPartSetHeader.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=299,
)


_CANONICALPROPOSAL = _descriptor.Descriptor(
  name='CanonicalProposal',
  full_name='tendermint.types.CanonicalProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='tendermint.types.CanonicalProposal.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.types.CanonicalProposal.height', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.types.CanonicalProposal.round', index=2,
      number=3, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pol_round', full_name='tendermint.types.CanonicalProposal.pol_round', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\010POLRound', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='tendermint.types.CanonicalProposal.block_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007BlockID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tendermint.types.CanonicalProposal.timestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\220\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.types.CanonicalProposal.chain_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007ChainID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=587,
)


_CANONICALVOTE = _descriptor.Descriptor(
  name='CanonicalVote',
  full_name='tendermint.types.CanonicalVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='tendermint.types.CanonicalVote.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.types.CanonicalVote.height', index=1,
      number=2, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.types.CanonicalVote.round', index=2,
      number=3, type=16, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='tendermint.types.CanonicalVote.block_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007BlockID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tendermint.types.CanonicalVote.timestamp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\220\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.types.CanonicalVote.chain_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007ChainID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=838,
)

_CANONICALBLOCKID.fields_by_name['part_set_header'].message_type = _CANONICALPARTSETHEADER
_CANONICALPROPOSAL.fields_by_name['type'].enum_type = tendermint_dot_types_dot_types__pb2._SIGNEDMSGTYPE
_CANONICALPROPOSAL.fields_by_name['block_id'].message_type = _CANONICALBLOCKID
_CANONICALPROPOSAL.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CANONICALVOTE.fields_by_name['type'].enum_type = tendermint_dot_types_dot_types__pb2._SIGNEDMSGTYPE
_CANONICALVOTE.fields_by_name['block_id'].message_type = _CANONICALBLOCKID
_CANONICALVOTE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['CanonicalBlockID'] = _CANONICALBLOCKID
DESCRIPTOR.message_types_by_name['CanonicalPartSetHeader'] = _CANONICALPARTSETHEADER
DESCRIPTOR.message_types_by_name['CanonicalProposal'] = _CANONICALPROPOSAL
DESCRIPTOR.message_types_by_name['CanonicalVote'] = _CANONICALVOTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CanonicalBlockID = _reflection.GeneratedProtocolMessageType('CanonicalBlockID', (_message.Message,), {
  'DESCRIPTOR' : _CANONICALBLOCKID,
  '__module__' : 'tendermint.types.canonical_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.CanonicalBlockID)
  })
_sym_db.RegisterMessage(CanonicalBlockID)

CanonicalPartSetHeader = _reflection.GeneratedProtocolMessageType('CanonicalPartSetHeader', (_message.Message,), {
  'DESCRIPTOR' : _CANONICALPARTSETHEADER,
  '__module__' : 'tendermint.types.canonical_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.CanonicalPartSetHeader)
  })
_sym_db.RegisterMessage(CanonicalPartSetHeader)

CanonicalProposal = _reflection.GeneratedProtocolMessageType('CanonicalProposal', (_message.Message,), {
  'DESCRIPTOR' : _CANONICALPROPOSAL,
  '__module__' : 'tendermint.types.canonical_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.CanonicalProposal)
  })
_sym_db.RegisterMessage(CanonicalProposal)

CanonicalVote = _reflection.GeneratedProtocolMessageType('CanonicalVote', (_message.Message,), {
  'DESCRIPTOR' : _CANONICALVOTE,
  '__module__' : 'tendermint.types.canonical_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.CanonicalVote)
  })
_sym_db.RegisterMessage(CanonicalVote)


DESCRIPTOR._options = None
_CANONICALBLOCKID.fields_by_name['part_set_header']._options = None
_CANONICALPROPOSAL.fields_by_name['pol_round']._options = None
_CANONICALPROPOSAL.fields_by_name['block_id']._options = None
_CANONICALPROPOSAL.fields_by_name['timestamp']._options = None
_CANONICALPROPOSAL.fields_by_name['chain_id']._options = None
_CANONICALVOTE.fields_by_name['block_id']._options = None
_CANONICALVOTE.fields_by_name['timestamp']._options = None
_CANONICALVOTE.fields_by_name['chain_id']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/oracle/v1beta1/events.proto',
  package='injective.oracle.v1beta1',
  syntax='proto3',
  serialized_options=b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%injective/oracle/v1beta1/events.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"|\n\x16SetChainlinkPriceEvent\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12>\n\x06\x61nswer\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\"\x9d\x01\n\x11SetBandPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0cresolve_time\x18\x04 \x01(\x04\x12\x12\n\nrequest_id\x18\x05 \x01(\x04\"\xb5\x01\n\x14SetBandIBCPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0f\n\x07symbols\x18\x02 \x03(\t\x12>\n\x06prices\x18\x03 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0cresolve_time\x18\x04 \x01(\x04\x12\x12\n\nrequest_id\x18\x05 \x01(\x04\x12\x11\n\tclient_id\x18\x06 \x01(\x03\"?\n\x16\x45ventBandIBCAckSuccess\x12\x12\n\nack_result\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\x03\"<\n\x14\x45ventBandIBCAckError\x12\x11\n\tack_error\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\x03\"0\n\x1b\x45ventBandIBCResponseTimeout\x12\x11\n\tclient_id\x18\x01 \x01(\x03\"\x85\x01\n\x16SetPriceFeedPriceEvent\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\t\x12\r\n\x05quote\x18\x03 \x01(\t\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x89\x01\n\x15SetProviderPriceEvent\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0f\n\x07relayer\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12=\n\x05price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"y\n\x15SetCoinbasePriceEvent\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x42NZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_SETCHAINLINKPRICEEVENT = _descriptor.Descriptor(
  name='SetChainlinkPriceEvent',
  full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answer', full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent.answer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.SetChainlinkPriceEvent.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=245,
)


_SETBANDPRICEEVENT = _descriptor.Descriptor(
  name='SetBandPriceEvent',
  full_name='injective.oracle.v1beta1.SetBandPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.SetBandPriceEvent.relayer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.SetBandPriceEvent.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.SetBandPriceEvent.price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='injective.oracle.v1beta1.SetBandPriceEvent.resolve_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.SetBandPriceEvent.request_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=405,
)


_SETBANDIBCPRICEEVENT = _descriptor.Descriptor(
  name='SetBandIBCPriceEvent',
  full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.relayer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.symbols', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prices', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.prices', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolve_time', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.resolve_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.request_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.SetBandIBCPriceEvent.client_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=589,
)


_EVENTBANDIBCACKSUCCESS = _descriptor.Descriptor(
  name='EventBandIBCAckSuccess',
  full_name='injective.oracle.v1beta1.EventBandIBCAckSuccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack_result', full_name='injective.oracle.v1beta1.EventBandIBCAckSuccess.ack_result', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.EventBandIBCAckSuccess.client_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=654,
)


_EVENTBANDIBCACKERROR = _descriptor.Descriptor(
  name='EventBandIBCAckError',
  full_name='injective.oracle.v1beta1.EventBandIBCAckError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack_error', full_name='injective.oracle.v1beta1.EventBandIBCAckError.ack_error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.EventBandIBCAckError.client_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=656,
  serialized_end=716,
)


_EVENTBANDIBCRESPONSETIMEOUT = _descriptor.Descriptor(
  name='EventBandIBCResponseTimeout',
  full_name='injective.oracle.v1beta1.EventBandIBCResponseTimeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='injective.oracle.v1beta1.EventBandIBCResponseTimeout.client_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=766,
)


_SETPRICEFEEDPRICEEVENT = _descriptor.Descriptor(
  name='SetPriceFeedPriceEvent',
  full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.relayer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.base', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.quote', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.SetPriceFeedPriceEvent.price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=902,
)


_SETPROVIDERPRICEEVENT = _descriptor.Descriptor(
  name='SetProviderPriceEvent',
  full_name='injective.oracle.v1beta1.SetProviderPriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='injective.oracle.v1beta1.SetProviderPriceEvent.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayer', full_name='injective.oracle.v1beta1.SetProviderPriceEvent.relayer', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.SetProviderPriceEvent.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.SetProviderPriceEvent.price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=1042,
)


_SETCOINBASEPRICEEVENT = _descriptor.Descriptor(
  name='SetCoinbasePriceEvent',
  full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective.oracle.v1beta1.SetCoinbasePriceEvent.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1165,
)

DESCRIPTOR.message_types_by_name['SetChainlinkPriceEvent'] = _SETCHAINLINKPRICEEVENT
DESCRIPTOR.message_types_by_name['SetBandPriceEvent'] = _SETBANDPRICEEVENT
DESCRIPTOR.message_types_by_name['SetBandIBCPriceEvent'] = _SETBANDIBCPRICEEVENT
DESCRIPTOR.message_types_by_name['EventBandIBCAckSuccess'] = _EVENTBANDIBCACKSUCCESS
DESCRIPTOR.message_types_by_name['EventBandIBCAckError'] = _EVENTBANDIBCACKERROR
DESCRIPTOR.message_types_by_name['EventBandIBCResponseTimeout'] = _EVENTBANDIBCRESPONSETIMEOUT
DESCRIPTOR.message_types_by_name['SetPriceFeedPriceEvent'] = _SETPRICEFEEDPRICEEVENT
DESCRIPTOR.message_types_by_name['SetProviderPriceEvent'] = _SETPROVIDERPRICEEVENT
DESCRIPTOR.message_types_by_name['SetCoinbasePriceEvent'] = _SETCOINBASEPRICEEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetChainlinkPriceEvent = _reflection.GeneratedProtocolMessageType('SetChainlinkPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETCHAINLINKPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetChainlinkPriceEvent)
  })
_sym_db.RegisterMessage(SetChainlinkPriceEvent)

SetBandPriceEvent = _reflection.GeneratedProtocolMessageType('SetBandPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETBANDPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetBandPriceEvent)
  })
_sym_db.RegisterMessage(SetBandPriceEvent)

SetBandIBCPriceEvent = _reflection.GeneratedProtocolMessageType('SetBandIBCPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETBANDIBCPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetBandIBCPriceEvent)
  })
_sym_db.RegisterMessage(SetBandIBCPriceEvent)

EventBandIBCAckSuccess = _reflection.GeneratedProtocolMessageType('EventBandIBCAckSuccess', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBANDIBCACKSUCCESS,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.EventBandIBCAckSuccess)
  })
_sym_db.RegisterMessage(EventBandIBCAckSuccess)

EventBandIBCAckError = _reflection.GeneratedProtocolMessageType('EventBandIBCAckError', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBANDIBCACKERROR,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.EventBandIBCAckError)
  })
_sym_db.RegisterMessage(EventBandIBCAckError)

EventBandIBCResponseTimeout = _reflection.GeneratedProtocolMessageType('EventBandIBCResponseTimeout', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBANDIBCRESPONSETIMEOUT,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.EventBandIBCResponseTimeout)
  })
_sym_db.RegisterMessage(EventBandIBCResponseTimeout)

SetPriceFeedPriceEvent = _reflection.GeneratedProtocolMessageType('SetPriceFeedPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETPRICEFEEDPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetPriceFeedPriceEvent)
  })
_sym_db.RegisterMessage(SetPriceFeedPriceEvent)

SetProviderPriceEvent = _reflection.GeneratedProtocolMessageType('SetProviderPriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETPROVIDERPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetProviderPriceEvent)
  })
_sym_db.RegisterMessage(SetProviderPriceEvent)

SetCoinbasePriceEvent = _reflection.GeneratedProtocolMessageType('SetCoinbasePriceEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETCOINBASEPRICEEVENT,
  '__module__' : 'injective.oracle.v1beta1.events_pb2'
  # @@protoc_insertion_point(class_scope:injective.oracle.v1beta1.SetCoinbasePriceEvent)
  })
_sym_db.RegisterMessage(SetCoinbasePriceEvent)


DESCRIPTOR._options = None
_SETCHAINLINKPRICEEVENT.fields_by_name['answer']._options = None
_SETBANDPRICEEVENT.fields_by_name['price']._options = None
_SETBANDIBCPRICEEVENT.fields_by_name['prices']._options = None
_SETPRICEFEEDPRICEEVENT.fields_by_name['price']._options = None
_SETPROVIDERPRICEEVENT.fields_by_name['price']._options = None
_SETCOINBASEPRICEEVENT.fields_by_name['price']._options = None
# @@protoc_insertion_point(module_scope)
